==> haskell-cmdargs-0.10.18-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cmdargs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cmdargs
version: 0.10.18
id: cmdargs-0.10.18-FddQmgeT9xb4xNYVbmZNzf
key: cmdargs-0.10.18-FddQmgeT9xb4xNYVbmZNzf
license: BSD3
copyright: Neil Mitchell 2009-2017
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/cmdargs#readme
synopsis: Command line argument processing
description:
    This library provides an easy way to define command line parsers. Most users
    will want to use the "System.Console.CmdArgs.Implicit" module, whose
    documentation contains an example.
    .
    * "System.Console.CmdArgs.Explicit" provides a way to write command line
    parsers for both single mode programs (most programs) and multiple
    mode programs (e.g. darcs or cabal). Parsers are defined by constructing
    a data structure.
    .
    * "System.Console.CmdArgs.Implicit" provides a way to concisely define
    command line parsers, up to three times shorter than getopt. These parsers
    are translated into the Explicit data type.
    .
    * "System.Console.CmdArgs.GetOpt" provides a wrapper allowing compatiblity
    with existing getopt parsers, mapping to the Explicit data type.
    .
    For a general reference on what command line flags are commonly used,
    see <http://www.faqs.org/docs/artu/ch10s05.html>.
category: Console
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    System.Console.CmdArgs System.Console.CmdArgs.Annotate
    System.Console.CmdArgs.Default System.Console.CmdArgs.Explicit
    System.Console.CmdArgs.GetOpt System.Console.CmdArgs.Helper
    System.Console.CmdArgs.Implicit System.Console.CmdArgs.Quote
    System.Console.CmdArgs.Text System.Console.CmdArgs.Verbosity
hidden-modules: Data.Generics.Any Data.Generics.Any.Prelude
                System.Console.CmdArgs.Explicit.Complete
                System.Console.CmdArgs.Explicit.ExpandArgsAt
                System.Console.CmdArgs.Explicit.Help
                System.Console.CmdArgs.Explicit.Process
                System.Console.CmdArgs.Explicit.SplitJoin
                System.Console.CmdArgs.Explicit.Type
                System.Console.CmdArgs.Implicit.Ann
                System.Console.CmdArgs.Implicit.Global
                System.Console.CmdArgs.Implicit.Local
                System.Console.CmdArgs.Implicit.Reader
                System.Console.CmdArgs.Implicit.Reform
                System.Console.CmdArgs.Implicit.Type
                System.Console.CmdArgs.Implicit.UI
abi: fc412fe8b8bc71de664bb3c452b9a90b
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/cmdargs-0.10.18
library-dirs: /usr/lib/ghc-8.2.1/site-local/cmdargs-0.10.18
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/cmdargs-0.10.18
hs-libraries: HScmdargs-0.10.18-FddQmgeT9xb4xNYVbmZNzf
depends:
    base-4.10.0.0 filepath-1.4.1.2 transformers-0.5.2.0 process-1.6.1.0
    template-haskell-2.12.0.0
abi-depends: base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             filepath-1.4.1.2=7f2f990ae2114c616de6dfc1a7f18a6e
             transformers-0.5.2.0=2645d250dd615ce454f807270041c5ea
             process-1.6.1.0=d01a8ca2c6610f40dfd0fe25f50afb10
             template-haskell-2.12.0.0=f12600dbe1b363b1dcebe6addb7b269e
haddock-interfaces: /usr/share/doc/haskell-cmdargs/html/cmdargs.haddock
haddock-html: /usr/share/doc/haskell-cmdargs/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cmdargs-0.10.18-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cmdargs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cmdargs
version: 0.10.18
id: cmdargs-0.10.18-6bkRWEoIaWqEtqIB64CQNf
key: cmdargs-0.10.18-6bkRWEoIaWqEtqIB64CQNf
license: BSD3
copyright: Neil Mitchell 2009-2017
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/cmdargs#readme
synopsis: Command line argument processing
description:
    This library provides an easy way to define command line parsers. Most users
    will want to use the "System.Console.CmdArgs.Implicit" module, whose
    documentation contains an example.
    .
    * "System.Console.CmdArgs.Explicit" provides a way to write command line
    parsers for both single mode programs (most programs) and multiple
    mode programs (e.g. darcs or cabal). Parsers are defined by constructing
    a data structure.
    .
    * "System.Console.CmdArgs.Implicit" provides a way to concisely define
    command line parsers, up to three times shorter than getopt. These parsers
    are translated into the Explicit data type.
    .
    * "System.Console.CmdArgs.GetOpt" provides a wrapper allowing compatiblity
    with existing getopt parsers, mapping to the Explicit data type.
    .
    For a general reference on what command line flags are commonly used,
    see <http://www.faqs.org/docs/artu/ch10s05.html>.
category: Console
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
indefinite: False
exposed-modules:
    System.Console.CmdArgs System.Console.CmdArgs.Annotate
    System.Console.CmdArgs.Default System.Console.CmdArgs.Explicit
    System.Console.CmdArgs.GetOpt System.Console.CmdArgs.Helper
    System.Console.CmdArgs.Implicit System.Console.CmdArgs.Quote
    System.Console.CmdArgs.Text System.Console.CmdArgs.Verbosity
hidden-modules: Data.Generics.Any Data.Generics.Any.Prelude
                System.Console.CmdArgs.Explicit.Complete
                System.Console.CmdArgs.Explicit.ExpandArgsAt
                System.Console.CmdArgs.Explicit.Help
                System.Console.CmdArgs.Explicit.Process
                System.Console.CmdArgs.Explicit.SplitJoin
                System.Console.CmdArgs.Explicit.Type
                System.Console.CmdArgs.Implicit.Ann
                System.Console.CmdArgs.Implicit.Global
                System.Console.CmdArgs.Implicit.Local
                System.Console.CmdArgs.Implicit.Reader
                System.Console.CmdArgs.Implicit.Reform
                System.Console.CmdArgs.Implicit.Type
                System.Console.CmdArgs.Implicit.UI
abi: d2ead4026b00faa2638870c5a7f7348b
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/cmdargs-0.10.18
library-dirs: /usr/lib/ghc-8.2.2/site-local/cmdargs-0.10.18
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/cmdargs-0.10.18
hs-libraries: HScmdargs-0.10.18-6bkRWEoIaWqEtqIB64CQNf
depends:
    base-4.10.1.0 filepath-1.4.1.2 transformers-0.5.2.0 process-1.6.1.0
    template-haskell-2.12.0.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             filepath-1.4.1.2=f49190c9093d895f9f159c40e7d1ff46
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             process-1.6.1.0=df30c64bceb5deb119c7833d040aa380
             template-haskell-2.12.0.0=2257617827b0258ca46e933b344007b7
haddock-interfaces: /usr/share/doc/haskell-cmdargs/html/cmdargs.haddock
haddock-html: /usr/share/doc/haskell-cmdargs/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
